@@ -40,7 +40,7 @@
  *
  * Copyright 1999-2000 (C) Intalio, Inc. All Rights Reserved.
  *
- * $Id: JField.java 1297 2009-07-23 01:17:35Z hboutemy $
+ * $Id$
  */
 
 package org.codehaus.modello.plugin.java.javasource;
@@ -73,7 +73,7 @@ package org.codehaus.modello.plugin.java.javasource;
  * This class is part of package which is used to
  * create source code in memory.
  * @author <a href="mailto:kvisco@intalio.com">Keith Visco</a>
- * @version $Revision: 1297 $ $Date: 2009-07-23 03:17:35 +0200 (jeu. 23 juil. 2009) $
+ * @version $Revision$ $Date$
  **/
 public class JField implements JMember
 {
@@ -236,7 +236,7 @@ public class JField implements JMember
 
     public String toString()
     {
-        StringBuffer sb = new StringBuffer();
+        StringBuilder sb = new StringBuilder();
         sb.append( modifiers.toString() );
         sb.append( ' ' );
         sb.append( type );
