@@ -37,7 +37,6 @@ import java.util.List;
 
 /**
  * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l </a>
- * @version $Id: XmlModelloPluginTest.java 1413 2010-02-13 21:23:01Z hboutemy $
  */
 public class XmlModelloPluginTest
     extends PlexusTestCase
@@ -55,7 +54,7 @@ public class XmlModelloPluginTest
     public void testXmlPlugin()
         throws Exception
     {
-        ModelloCore modello = (ModelloCore) container.lookup( ModelloCore.ROLE );
+        ModelloCore modello = (ModelloCore) lookup( ModelloCore.ROLE );
 
         Model model = modello.loadModel( getTestFile( "src/test/resources/model.mdo" ) );
 
